# trello\_backup\_renderer

Generates HTML files for [Trello](http://trello.com) boards from backups created by [jtpio/trello-full-backup](https://github.com/jtpio/trello-full-backup).

* Unlike Trello's built-in print functionality, it includes all card cover images and comments for the board in a single document.
* Can be run locally without authorizing a third-party service to access your Trello data.

You can view a sample file generated by the tool [here](spec/test_board/Renderer%20Test%20Board_full.html).

(I am not affiliated with Trello in any way.)

## Installation

    $ gem install trello_backup_renderer

## Usage

First, use [jtpio/trello-full-backup](https://github.com/jtpio/trello-full-backup) to create a backup of your board.
It's important to use the `-t` option.

Then find the folder in which the backup was created.
This should contain a file `BOARD_NAME_full.json`, and folders such as `0_someLongLIstId`.
`trello_backup_renderer` uses the full.json file and also uses the files in the nested `attachments` directories, and depends on the folder name format that trello-full-backup generates.
(It does not use the `card.json` or `description.md` files that trello-full-backup generates.)

Run the tool like this:

    $ trello_backup_renderer PATH_TO_BOARD_BACKUP_DIR

This will create a `BOARD_NAME_full.html` file in the given directory.
This file may contain relative links to the attachment files in that directory.

## Options

A default stylesheet is embedded into the HTML file; if you don't want it included, use the `--omit-styles` option.
You can also link to your own stylesheet using the `--head-insert` option:

    $ trello_backup_renderer PATH_TO_BOARD_BACKUP_DIR --omit-styles --insert-head='<link href="path/to/stylesheet.css" rel="stylesheet">'

By default, the full name of every comment author is included along with the comment.
If the board is private and has only one comment author, you may wish to omit their name.
To do this, use the `--hide-authorship` option:

    $ trello_backup_renderer PATH_TO_BOARD_BACKUP_DIR --hide-authorship

## Supported Features

Currently only the following data is included in the generated HTML page:

- Lists
  - Names
- Cards
  - Covers (when they're attachments)
  - Names
  - Labels (name and color)
  - Descriptions (without formatting)
  - Comments (without formatting)

## Development

After checking out the repo, run `bin/setup` to install dependencies. Then, run `rake spec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

A script `bin/scrub_test_data` is included which can be run against a board backup directory to remove attributes and files which are unused by trello_backup_renderer and replace IDs and member names with placeholder values.
This was used in creating the test data seen in `spec/test_board`.
Warning: The `scrub_test_data` script deletes data from the specified directory in-place.

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/brokensandals/trello_backup_renderer.

## License

The gem is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).
